import 'dart:io';

import 'package:web_socket_channel/io.dart';
import 'package:web_socket_channel/web_socket_channel.dart';

typedef OnMessage = void Function(String messageStr);

class HttpEndpoint {
  String uri;
  HttpEndpoint(this.uri);

  Future<bool> post(String body) async {
    final client = HttpClient();
    final request = await client.postUrl(Uri.parse(uri));
    request.write(body);
    final response = await request.close();
    if (response.statusCode >= 200 && response.statusCode < 300) {
      return true;
    }
    return false;
  }
}

class ChannelService {
  String roomId;
  String me;
  late WebSocketChannel channel;
  ChannelService(this.roomId, this.me) {
    final url = 'wss://api.codiario.com/chatroom/$roomId/with/$me';
    print('will connect to socks:$url');
    channel = IOWebSocketChannel.connect(
      Uri.parse(url),
    );
    print('connected to socks:$url');
    channel.sink.add('test!');
  }

  void lookingForMessage(OnMessage messageHandler) {
    channel.sink.add('ping!');
    print('send pint!');
    channel.stream.listen((event) {
      print('get ev:$event');
      messageHandler(event);
    }, onError: (ex, st) {
      print('断开连接：$ex \n $st');
    }, onDone: () {
      print('连接已断开');
    });
  }

  void sendMessage(String message) {
    channel.sink.add(message);
  }
}
